==> aws_cdk.aws_codedeploy-0.26.0-py3-none-any.whl: package/lib/lambda/deployment-config.d.ts <==
import cdk = require('@aws-cdk/cdk');
/**
 * The Deployment Configuration of a Lambda Deployment Group.
 * The default, pre-defined Configurations are available as constants on the {@link LambdaDeploymentConfig} class
 * (`LambdaDeploymentConfig.AllAtOnce`, `LambdaDeploymentConfig.Canary10Percent30Minutes`, etc.).
 *
 * Note: CloudFormation does not currently support creating custom lambda configs outside
 * of using a custom resource. You can import custom deployment config created outside the
 * CDK or via a custom resource with {@link LambdaDeploymentConfig#import}.
 */
export interface ILambdaDeploymentConfig {
    readonly deploymentConfigName: string;
    deploymentConfigArn(scope: cdk.IConstruct): string;
}
/**
 * Properties of a reference to a CodeDeploy Lambda Deployment Configuration.
 *
 * @see LambdaDeploymentConfig#import
 * @see LambdaDeploymentConfig#export
 */
export interface LambdaDeploymentConfigImportProps {
    /**
     * The physical, human-readable name of the custom CodeDeploy Lambda Deployment Configuration
     * that we are referencing.
     */
    readonly deploymentConfigName: string;
}
/**
 * A custom Deployment Configuration for a Lambda Deployment Group.
 *
 * Note: This class currently stands as namespaced container of the default configurations
 * until CloudFormation supports custom Lambda Deployment Configs. Until then it is closed
 * (private constructor) and does not extend {@link cdk.Construct}
 */
export declare class LambdaDeploymentConfig {
    static readonly AllAtOnce: ILambdaDeploymentConfig;
    static readonly Canary10Percent30Minutes: ILambdaDeploymentConfig;
    static readonly Canary10Percent5Minutes: ILambdaDeploymentConfig;
    static readonly Canary10Percent10Minutes: ILambdaDeploymentConfig;
    static readonly Canary10Percent15Minutes: ILambdaDeploymentConfig;
    static readonly Linear10PercentEvery10Minutes: ILambdaDeploymentConfig;
    static readonly Linear10PercentEvery1Minute: ILambdaDeploymentConfig;
    static readonly Linear10PercentEvery2Minutes: ILambdaDeploymentConfig;
    static readonly Linear10PercentEvery3Minutes: ILambdaDeploymentConfig;
    /**
     * Import a custom Deployment Configuration for a Lambda Deployment Group defined outside the CDK.
     *
     * @param scope the parent Construct for this new Construct
     * @param id the logical ID of this new Construct
     * @param props the properties of the referenced custom Deployment Configuration
     * @returns a Construct representing a reference to an existing custom Deployment Configuration
     */
    static import(scope: cdk.Construct, id: string, props: LambdaDeploymentConfigImportProps): ILambdaDeploymentConfig;
    private constructor();
}

==> aws_cdk.aws_codedeploy-0.35.0-py3-none-any.whl: package/lib/lambda/deployment-config.d.ts <==
import cdk = require('@aws-cdk/cdk');
/**
 * The Deployment Configuration of a Lambda Deployment Group.
 * The default, pre-defined Configurations are available as constants on the {@link LambdaDeploymentConfig} class
 * (`LambdaDeploymentConfig.AllAtOnce`, `LambdaDeploymentConfig.Canary10Percent30Minutes`, etc.).
 *
 * Note: CloudFormation does not currently support creating custom lambda configs outside
 * of using a custom resource. You can import custom deployment config created outside the
 * CDK or via a custom resource with {@link LambdaDeploymentConfig#import}.
 */
export interface ILambdaDeploymentConfig {
    readonly deploymentConfigName: string;
    readonly deploymentConfigArn: string;
}
/**
 * Properties of a reference to a CodeDeploy Lambda Deployment Configuration.
 *
 * @see LambdaDeploymentConfig#import
 * @see LambdaDeploymentConfig#export
 */
export interface LambdaDeploymentConfigImportProps {
    /**
     * The physical, human-readable name of the custom CodeDeploy Lambda Deployment Configuration
     * that we are referencing.
     */
    readonly deploymentConfigName: string;
}
/**
 * A custom Deployment Configuration for a Lambda Deployment Group.
 *
 * Note: This class currently stands as namespaced container of the default configurations
 * until CloudFormation supports custom Lambda Deployment Configs. Until then it is closed
 * (private constructor) and does not extend {@link cdk.Construct}
 *
 * @resource AWS::CodeDeploy::DeploymentConfig
 */
export declare class LambdaDeploymentConfig {
    static readonly AllAtOnce: ILambdaDeploymentConfig;
    static readonly Canary10Percent30Minutes: ILambdaDeploymentConfig;
    static readonly Canary10Percent5Minutes: ILambdaDeploymentConfig;
    static readonly Canary10Percent10Minutes: ILambdaDeploymentConfig;
    static readonly Canary10Percent15Minutes: ILambdaDeploymentConfig;
    static readonly Linear10PercentEvery10Minutes: ILambdaDeploymentConfig;
    static readonly Linear10PercentEvery1Minute: ILambdaDeploymentConfig;
    static readonly Linear10PercentEvery2Minutes: ILambdaDeploymentConfig;
    static readonly Linear10PercentEvery3Minutes: ILambdaDeploymentConfig;
    /**
     * Import a custom Deployment Configuration for a Lambda Deployment Group defined outside the CDK.
     *
     * @param _scope the parent Construct for this new Construct
     * @param _id the logical ID of this new Construct
     * @param props the properties of the referenced custom Deployment Configuration
     * @returns a Construct representing a reference to an existing custom Deployment Configuration
     */
    static import(_scope: cdk.Construct, _id: string, props: LambdaDeploymentConfigImportProps): ILambdaDeploymentConfig;
    private constructor();
}
